@@ -3,7 +3,7 @@
 # MODEVAL.TCL, module evaluation procedures
 # Copyright (C) 2002-2004 Mark Lakata
 # Copyright (C) 2004-2017 Kent Mein
-# Copyright (C) 2016-2022 Xavier Delaruelle
+# Copyright (C) 2016-2023 Xavier Delaruelle
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -541,7 +541,7 @@ proc pushSettings {} {
       g_loadedModuleAliasAltname g_moduleDepend g_dependHash\
       g_moduleNPODepend g_dependNPOHash g_prereqViolation\
       g_prereqNPOViolation g_conflictViolation g_moduleUnmetDep\
-      g_unmetDepHash g_moduleEval g_moduleHiddenEval} {
+      g_unmetDepHash g_moduleEval g_moduleHiddenEval g_scanModuleVariant} {
       ##nagelfar ignore Suspicious variable name
       lappend ::g_SAVE_$var [array get ::$var]
    }
@@ -568,7 +568,7 @@ proc popSettings {} {
       g_loadedModuleAliasAltname g_moduleDepend g_dependHash\
       g_moduleNPODepend g_dependNPOHash g_prereqViolation\
       g_prereqNPOViolation g_conflictViolation g_moduleUnmetDep\
-      g_unmetDepHash g_moduleEval g_moduleHiddenEval} {
+      g_unmetDepHash g_moduleEval g_moduleHiddenEval g_scanModuleVariant} {
       ##nagelfar ignore Suspicious variable name
       set ::g_SAVE_$var [lrange [set ::g_SAVE_$var] 0 end-1]
    }
@@ -584,7 +584,7 @@ proc restoreSettings {} {
       g_loadedModuleAliasAltname g_moduleDepend g_dependHash\
       g_moduleNPODepend g_dependNPOHash g_prereqViolation\
       g_prereqNPOViolation g_conflictViolation g_moduleUnmetDep\
-      g_unmetDepHash g_moduleEval g_moduleHiddenEval} {
+      g_unmetDepHash g_moduleEval g_moduleHiddenEval g_scanModuleVariant} {
       # clear current $var arrays
       ##nagelfar ignore #5 Suspicious variable name
       if {[info exists ::$var]} {
@@ -739,7 +739,7 @@ proc reloadModuleListLoadPhase {lmname isuaskedlist vrlist extrataglist\
    setConf auto_handling 0
    foreach mod $lmlist {
       # if an auto set default was excluded, module spec need parsing
-      lassign [parseModuleSpecification 0 $mod {*}$vr($mod)] modnamevr
+      lassign [parseModuleSpecification 0 0 0 0 $mod {*}$vr($mod)] modnamevr
       # reload module with user asked property and extra tags preserved
       if {[cmdModuleLoad $context $isuasked($mod) 0 0 $extratag($mod)\
          $modnamevr]} {
