@@ -34,7 +34,7 @@ proc variant-sc {itrp args} {
       }
    }
 
-   recordScanModuleElt [currentState modulename] $name variant
+   recordScanModuleElt $name variant
 
    lappend ::g_scanModuleVariant([currentState modulename]) [list $name\
       $values $defdflvalue $dflvalue $isboolean]
@@ -47,7 +47,7 @@ proc variant-sc {itrp args} {
 proc setenv-sc {args} {
    lassign [parseSetenvCommandArgs load set {*}$args] bhv var val
 
-   recordScanModuleElt [currentState modulename] $var setenv envvar
+   recordScanModuleElt $var setenv envvar
 
    if {![info exists ::env($var)]} {
       set ::env($var) {}
@@ -59,7 +59,7 @@ proc edit-path-sc {cmd args} {
    lassign [parsePathCommandArgs $cmd load noop {*}$args] separator allow_dup\
       idx_val ign_refcount bhv var path_list
 
-   recordScanModuleElt [currentState modulename] $var $cmd envvar
+   recordScanModuleElt $var $cmd envvar
 
    if {![info exists ::env($var)]} {
       set ::env($var) {}
@@ -68,7 +68,7 @@ proc edit-path-sc {cmd args} {
 }
 
 proc pushenv-sc {var val} {
-   recordScanModuleElt [currentState modulename] $var pushenv envvar
+   recordScanModuleElt $var pushenv envvar
 
    if {![info exists ::env($var)]} {
       set ::env($var) {}
@@ -79,7 +79,7 @@ proc pushenv-sc {var val} {
 proc unsetenv-sc {args} {
    lassign [parseUnsetenvCommandArgs load noop {*}$args] bhv var val
 
-   recordScanModuleElt [currentState modulename] $var unsetenv envvar
+   recordScanModuleElt $var unsetenv envvar
 
    if {![info exists ::env($var)]} {
       set ::env($var) {}
@@ -92,7 +92,7 @@ proc complete-sc {shell name body} {
       knerror "Invalid command name '$name'"
    }
 
-   recordScanModuleElt [currentState modulename] $name complete
+   recordScanModuleElt $name complete
 }
 
 proc uncomplete-sc {name} {
@@ -100,34 +100,34 @@ proc uncomplete-sc {name} {
       knerror "Invalid command name '$name'"
    }
 
-   recordScanModuleElt [currentState modulename] $name uncomplete
+   recordScanModuleElt $name uncomplete
 }
 
 proc set-alias-sc {alias what} {
-   recordScanModuleElt [currentState modulename] $alias set-alias
+   recordScanModuleElt $alias set-alias
 }
 
 proc unset-alias-sc {alias} {
-   recordScanModuleElt [currentState modulename] $alias unset-alias
+   recordScanModuleElt $alias unset-alias
 }
 
 proc set-function-sc {function what} {
-   recordScanModuleElt [currentState modulename] $function set-function
+   recordScanModuleElt $function set-function
 }
 
 proc unset-function-sc {function} {
-   recordScanModuleElt [currentState modulename] $function unset-function
+   recordScanModuleElt $function unset-function
 }
 
 proc chdir-sc {dir} {
-   recordScanModuleElt [currentState modulename] $dir chdir
+   recordScanModuleElt $dir chdir
 }
 
 proc family-sc {name} {
    if {[string length $name] == 0 || ![regexp {^[A-Za-z0-9_]*$} $name]} {
       knerror "Invalid family name '$name'"
    }
-   recordScanModuleElt [currentState modulename] $name family
+   recordScanModuleElt $name family
 }
 
 proc prereq-sc {args} {
@@ -135,8 +135,7 @@ proc prereq-sc {args} {
       opt_list args
 
    foreach modspec [parseModuleSpecification 0 0 0 0 {*}$args] {
-      recordScanModuleElt [currentState modulename] $modspec prereq\
-         prereq-any require
+      recordScanModuleElt $modspec prereq prereq-any require
    }
 }
 
@@ -145,8 +144,7 @@ proc prereq-all-sc {args} {
       opt_list args
 
    foreach modspec [parseModuleSpecification 0 0 0 0 {*}$args] {
-      recordScanModuleElt [currentState modulename] $modspec prereq-all\
-         depends-on require
+      recordScanModuleElt $modspec prereq-all depends-on require
    }
 }
 
@@ -155,14 +153,13 @@ proc always-load-sc {args} {
       opt_list args
 
    foreach modspec [parseModuleSpecification 0 0 0 0 {*}$args] {
-      recordScanModuleElt [currentState modulename] $modspec always-load\
-         require
+      recordScanModuleElt $modspec always-load require
    }
 }
 
 proc conflict-sc {args} {
    foreach modspec [parseModuleSpecification 0 0 0 0 {*}$args] {
-      recordScanModuleElt [currentState modulename] $modspec conflict incompat
+      recordScanModuleElt $modspec conflict incompat
    }
 }
 
@@ -175,47 +172,53 @@ proc module-sc {command args} {
          show_mtime show_filter search_filter search_match dump_state\
          addpath_pos not_req tag_list args
       set modspeclist [parseModuleSpecification 0 0 0 0 {*}$args]
+
+      # no require/incompat extra specifier alias if --not-req option is set
+      if {$not_req} {
+         set xtaliasinc {}
+         set xtaliasreq {}
+      } else {
+         set xtaliasinc [list incompat]
+         set xtaliasreq [list require]
+      }
+
       if {$command eq {switch}} {
          # distinguish switched-off module spec from switched-on
          # ignore command without or with too much argument
          switch -- [llength $modspeclist] {
             {1} {
                # no switched-off module with one-arg form
-               recordScanModuleElt [currentState modulename] $modspeclist\
-                  switch switch-on require
+               recordScanModuleElt $modspeclist switch switch-on\
+                  {*}$xtaliasreq
             }
             {2} {
                lassign $modspeclist swoffarg swonarg
-               recordScanModuleElt [currentState modulename] $swoffarg switch\
-                  switch-off incompat
-               recordScanModuleElt [currentState modulename] $swonarg switch\
-                  switch-on require
+               recordScanModuleElt $swoffarg switch switch-off {*}$xtaliasinc
+               recordScanModuleElt $swonarg switch switch-on {*}$xtaliasreq
             }
          }
       } else {
-         set xtalias [expr {$command eq {unload} ? {incompat} : {require}}]
+         set xtalias [expr {$command eq {unload} ? $xtaliasinc : $xtaliasreq}]
          # record each module spec
          foreach modspec $modspeclist {
-            recordScanModuleElt [currentState modulename] $modspec $command\
-               $xtalias
+            recordScanModuleElt $modspec $command {*}$xtalias
          }
       }
    }
 }
 
-proc recordScanModuleElt {mod name args} {
+proc recordScanModuleElt {name args} {
+   set mod [currentState modulename]
+   set modpath [currentState modulepath]
    if {![info exists ::g_scanModuleElt]} {
       set ::g_scanModuleElt [dict create]
    }
    foreach elt $args {
-      if {![dict exists $::g_scanModuleElt $elt]} {
-         dict set ::g_scanModuleElt $elt {}
-      }
-      if {![dict exists $::g_scanModuleElt $elt $name]} {
-         dict set ::g_scanModuleElt $elt $name [list $mod]
+      if {![dict exists $::g_scanModuleElt $modpath $elt $name]} {
+         dict set ::g_scanModuleElt $modpath $elt $name [list $mod]
       } else {
          ##nagelfar ignore Suspicious variable name
-         dict with ::g_scanModuleElt $elt {lappend $name $mod}
+         dict with ::g_scanModuleElt $modpath $elt {lappend $name $mod}
       }
       reportDebug "Module $mod defines $elt:$name"
    }
@@ -229,20 +232,15 @@ proc doesModVariantMatch {mod pvrlist} {
          set availvrarr([lindex $availvr 0]) [lindex $availvr 1]
          set availvrisbool([lindex $availvr 0]) [lindex $availvr 4]
       }
-      foreach pvr $pvrlist {
-         set pvrarr([lindex $pvr 0]) [lindex $pvr 1]
-         set pvrisbool([lindex $pvr 0]) [lindex $pvr 2]
-      }
-
       # no match if a specified variant is not found among module variants or
       # if the value is not available
-      foreach vrname [array names pvrarr] {
+      foreach pvr $pvrlist {
+         lassign $pvr vrname pvrval pvrisbool
          # if variant is a boolean, specified value should be a boolean too
          # any value accepted for free-value variant
          if {![info exists availvrarr($vrname)] || ($availvrisbool($vrname)\
-            && !$pvrisbool($vrname)) || (!$availvrisbool($vrname) && [llength\
-            $availvrarr($vrname)] > 0 && $pvrarr($vrname) ni\
-            $availvrarr($vrname))} {
+            && !$pvrisbool) || (!$availvrisbool($vrname) && [llength\
+            $availvrarr($vrname)] > 0 && $pvrval ni $availvrarr($vrname))} {
             set ret 0
             break
          }
@@ -254,29 +252,32 @@ proc doesModVariantMatch {mod pvrlist} {
 }
 
 # collect list of modules matching all extra specifier criteria
-proc getModMatchingExtraSpec {pxtlist} {
+proc getModMatchingExtraSpec {modpath pxtlist} {
    set res [list]
-   if {[info exists ::g_scanModuleElt]} {
+   if {[info exists ::g_scanModuleElt] && [dict exists $::g_scanModuleElt\
+      $modpath]} {
       foreach pxt $pxtlist {
          lassign $pxt elt name
          set one_crit_res [list]
          if {$elt in {require incompat load unload prereq conflict prereq-all\
             prereq-any depends-on always-load load-any try-load switch\
             switch-on switch-off}} {
-            if {[dict exists $::g_scanModuleElt $elt]} {
-               foreach modspec [dict get $::g_scanModuleElt $elt] {
+            if {[dict exists $::g_scanModuleElt $modpath $elt]} {
+               foreach {modspec values} [dict get $::g_scanModuleElt $modpath\
+                  $elt] {
                   # modEq proc has been initialized in getModules phase #2
                   if {[modEq $modspec $name eqstart 1 5 1]} {
                      # possible duplicate module entry in result list
                      lappend one_crit_res {*}[dict get $::g_scanModuleElt\
-                        $elt $modspec]
+                        $modpath $elt $modspec]
                   }
                }
             }
          } else {
             # get modules matching one simple extra specifier criterion
-            if {[dict exists $::g_scanModuleElt $elt $name]} {
-               set one_crit_res [dict get $::g_scanModuleElt $elt $name]
+            if {[dict exists $::g_scanModuleElt $modpath $elt $name]} {
+               set one_crit_res [dict get $::g_scanModuleElt $modpath\
+                  $elt $name]
             }
          }
          lappend all_crit_res $one_crit_res
@@ -305,7 +306,7 @@ proc isExtraMatchSearchRequired {mod} {
 }
 
 # perform extra match search on currently being built module search result
-proc filterExtraMatchSearch {mod res_arrname versmod_arrname} {
+proc filterExtraMatchSearch {modpath mod res_arrname versmod_arrname} {
    # link to variables/arrays from upper context
    upvar $res_arrname found_list
    upvar $versmod_arrname versmod_list
@@ -335,7 +336,7 @@ proc filterExtraMatchSearch {mod res_arrname versmod_arrname} {
             if {![isModuleTagged $elt forbidden 0]} {
                ##nagelfar ignore Suspicious variable name
                execute-modulefile [lindex $found_list($elt) 2] $elt $elt $elt\
-                  0 0
+                  0 0 $modpath
             }
          }
       }
@@ -364,7 +365,7 @@ proc filterExtraMatchSearch {mod res_arrname versmod_arrname} {
    # get list of modules matching extra specifiers to determine those to not
    # matching that need to be withdrawn from result
    if {$check_extra} {
-      set extra_keep_list [getModMatchingExtraSpec $spec_xt_list]
+      set extra_keep_list [getModMatchingExtraSpec $modpath $spec_xt_list]
       lassign [getDiffBetweenList $keep_list $extra_keep_list]\
          extra_unset_list
       set unset_list [list {*}$unset_list {*}$extra_unset_list]
